@@ -4,10 +4,8 @@ Grains for NVMe Qualified Names (NQN).
 """
 import aiofiles
 import errno
-import logging
-import os
 
-log = logging.getLogger(__name__)
+import os
 
 
 async def load_nvme_nqn(hub):
@@ -26,7 +24,7 @@ async def load_nvme_nqn(hub):
                         nvme_nqn.append(line)
         except IOError as ex:
             if ex.errno != errno.ENOENT:
-                log.debug(f"Error while accessing '{initiator}': {ex}")
+                hub.log.debug(f"Error while accessing '{initiator}': {ex}")
 
     if nvme_nqn:
         hub.corn.CORN.nvme_nqn = nvme_nqn
