@@ -1,11 +1,9 @@
 import asyncio
-import logging
+
 import re
 import shutil
 from typing import Any, Dict, List, Tuple
 
-log = logging.getLogger(__name__)
-
 
 async def _cidr_to_ipv4_netmask(cidr_bits: int) -> str:
     """
@@ -250,7 +248,7 @@ async def load_interfaces(hub):
     Provide a dict of the connected interfaces and their ip addresses
     The addresses will be passed as a list for each interface
     """
-    log.debug("Loading interfaces")
+    hub.log.debug("Loading interfaces")
     # Provides:
     #   ip_interfaces
     ipv4 = []
@@ -271,7 +269,9 @@ async def load_interfaces(hub):
         ret = await hub.exec.cmd.run(f"{ifconfig_path} -a")
         interfaces = await _interfaces_ifconfig(str(ret.stdout.strip()))
     else:
-        log.info("Unable to find commands `ip` or `ifconfig` to detect network devices")
+        hub.log.info(
+            "Unable to find commands `ip` or `ifconfig` to detect network devices"
+        )
         return
 
     interface: str
