@@ -20,9 +20,12 @@ async def _load_cgroup(hub) -> str:
     path = "/proc/1/cgroup"
     if os.path.exists(path):
         async with aiofiles.open(path) as fh_:
-            async for line in fh_:
-                if line.startswith("name="):
-                    return line.split(":")[0].split("=")[1]
+            data = await fh_.read()
+            if "docker" in data:
+                return "docker"
+            elif "name=" in data:
+                name = data.split("name=")[1]
+                return name.split(":")[0]
 
 
 async def load_init(hub):
